import { ComputedRef } from 'vue';
import ZMP, { ZMPPlugin } from 'zmp-core/types';
import { Store } from 'zmp-core/types';

import AccordionContent from './components/accordion-content/accordion-content';
import AccordionItem from './components/accordion-item/accordion-item';
import AccordionToggle from './components/accordion-toggle/accordion-toggle';
import Accordion from './components/accordion/accordion';
import ActionsButton from './components/actions-button/actions-button';
import ActionsGroup from './components/actions-group/actions-group';
import ActionsLabel from './components/actions-label/actions-label';
import Actions from './components/actions/actions';
import App from './components/app/app';
import AvatarGroup from './components/avatar-group/avatar-group';
import Avatar from './components/avatar/avatar';
import Box from './components/box/box';
import Button from './components/button/button';
import Card from './components/card/card';
import Checkbox from './components/checkbox/checkbox';
import Col from './components/col/col';
import DatePicker from './components/date-picker/date-picker';
import FabBackdrop from './components/fab-backdrop/fab-backdrop';
import FabButton from './components/fab-button/fab-button';
import FabButtons from './components/fab-buttons/fab-buttons';
import Fab from './components/fab/fab';
import GridItem from './components/grid-item/grid-item';
import Grid from './components/grid/grid';
import Icon from './components/icon/icon';
import Input from './components/input/input';
import Link from './components/link/link';
import ListInput from './components/list-input/list-input';
import ListItem from './components/list-item/list-item';
import List from './components/list/list';
import NavLeft from './components/nav-left/nav-left';
import NavRight from './components/nav-right/nav-right';
import NavTitleLarge from './components/nav-title-large/nav-title-large';
import NavTitle from './components/nav-title/nav-title';
import Navbar from './components/navbar/navbar';
import Page from './components/page/page';
import Picker from './components/picker/picker';
import Preloader from './components/preloader/preloader';
import Progressbar from './components/progressbar/progressbar';
import Radio from './components/radio/radio';
import Range from './components/range/range';
import Row from './components/row/row';
import Searchbar from './components/searchbar/searchbar';
import Sheet from './components/sheet/sheet';
import SkeletonAvatar from './components/skeleton-avatar/skeleton-avatar';
import SkeletonBlock from './components/skeleton-block/skeleton-block';
import SkeletonImage from './components/skeleton-image/skeleton-image';
import SkeletonText from './components/skeleton-text/skeleton-text';
import SwiperSlide from './components/swiper-slide/swiper-slide';
import Swiper from './components/swiper/swiper';
import Tab from './components/tab/tab';
import Tabbar from './components/tabbar/tabbar';
import Tabs from './components/tabs/tabs';
import Text from './components/text/text';
import Title from './components/title/title';
import ToastPreloader from './components/toast-preloader/toast-preloader';
import Toggle from './components/toggle/toggle';
import View from './components/view/view';

export interface ZMPTheme {
  ios: boolean;
  md: boolean;
  aurora: boolean;
}

/** Object with boolean properties with information about currently used theme (iOS, MD or Aurora) */
declare const theme: ZMPTheme;

/** Main ZMP's initialized instance. It allows you to use any of ZMP APIs */
declare const zmp: ZMP;

/** Callback function that will be executed when ZMP fully intialized. Useful to use in components when you need to access ZMP API and to be sure it is ready. So it is safe to put all ZMP related logic into this callback. As an argument it receives initialized ZMP instance */
declare const zmpready: (callback: (zmp: ZMP) => void) => void;

declare const ZMPVue: ZMPPlugin;

declare const registerComponents: (app: any) => void;

interface useStore<T = any> {
  (store: Store, getter: string): ComputedRef<T>;
  (getter: string): ComputedRef<T>;
}

declare const useStore: useStore;

export { AccordionContent, AccordionItem, AccordionToggle, Accordion, ActionsButton, ActionsGroup, ActionsLabel, Actions, App, AvatarGroup, Avatar, Box, Button, Card, Checkbox, Col, DatePicker, FabBackdrop, FabButton, FabButtons, Fab, GridItem, Grid, Icon, Input, Link, ListInput, ListItem, List, NavLeft, NavRight, NavTitleLarge, NavTitle, Navbar, Page, Picker, Preloader, Progressbar, Radio, Range, Row, Searchbar, Sheet, SkeletonAvatar, SkeletonBlock, SkeletonImage, SkeletonText, SwiperSlide, Swiper, Tab, Tabbar, Tabs, Text, Title, ToastPreloader, Toggle, View }
export { zmp, zmpready, theme, registerComponents, useStore };
export default ZMPVue;
